==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/sv.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Uppgifter",
    "Due yesterday" : "Förföll igår",
    "Due today" : "Förfaller idag",
    "Due tomorrow" : "Förfaller imorgon",
    "Due on" : "Förfaller",
    "Started yesterday" : "Startade igår",
    "Starts today" : "Startar idag",
    "Starts tomorrow" : "Startar imorgon",
    "Started on" : "Startade",
    "Starts on" : "Startar på",
    "[Remind me yesterday at ]HH:mm" : "[Påminn mig igår kl ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Påminn mig idag kl ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Påminn mig imorgon kl ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Påminn mig den ]MMM DD, YYYY,[ kl ]HH:mm",
    "Yesterday" : "Igår",
    "Today" : "Idag",
    "Tomorrow" : "Imorgon",
    "in %s" : "om %s",
    "%s ago" : "%s sedan",
    "seconds" : "sekunder",
    "a minute" : "en minut",
    "%d minutes" : "%d minuter",
    "an hour" : "en timme",
    "%d hours" : "%d timmar",
    "a day" : "en dag",
    "%d days" : "%d dagar",
    "a month" : "en månad",
    "%d months" : "%d månader",
    "a year" : "ett år",
    "%d years" : "%d år",
    "week" : "vecka",
    "weeks" : "veckor",
    "day" : "dag",
    "days" : "dagar",
    "hour" : "timme",
    "hours" : "timmar",
    "minute" : "minut",
    "minutes" : "minuter",
    "second" : "sekund",
    "before beginning" : "före början",
    "after beginning" : "efter början",
    "before end" : "före utgång",
    "after end" : "efter utgång",
    "Comment" : "Kommentar",
    "Add a comment" : "Lägg till en kommentar",
    "This will delete the Calendar \"%s\" and all of its entries." : "Detta kommer att radera kalenderns \"%s\" och alla dess poster.",
    "The name \"%s\" is already used." : "Namnet \"%s\" används redan.",
    "An empty name is not allowed." : "Ett tomt namn är inte tillåtet.",
    "Hidden" : "Gömd",
    "Visible" : "Synlig",
    "Automatic" : "Automatisk",
    "Sunday" : "söndag",
    "Monday" : "måndag",
    "Tuesday" : "tisdag",
    "Wednesday" : "onsdag",
    "Thursday" : "torsdag",
    "Friday" : "fredag",
    "Saturday" : "lördag",
    "Add an important item in \"%s\"..." : "Lägg till en viktig post i \"%s\" ...",
    "Add an item due today in \"%s\"..." : "Lägg till en post som förfaller idag i \"%s\" ...",
    "Add an item in \"%s\"..." : "Lägg till en post i \"%s\" ...",
    "Add a current item in \"%s\"..." : "Lägg till en nuvarande post i \"%s\" ...",
    "Add a subtask to \"%s\"..." : "Lägg till en under-anteckning i \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n slutförda uppgifter","%n slutförda uppgifter"],
    "Hours" : "Timmar",
    "Minutes" : "Minuter",
    "Set due date" : "Sätt slutdatum",
    "%s %% completed" : "%s %% slutfört",
    "priority %s: " : "Prioritet %s:",
    "high" : "Hög",
    "medium" : "medium",
    "low" : "Låg",
    "no priority assigned" : "ingen prioritet tilldelad",
    "Remind me" : "Påminn mig",
    "at the end" : "vid slutet",
    "at the beginning" : "vid början",
    "Set start date" : "Sätt startdatum",
    "{calendar} shared by {owner}" : "{calendar} delad utav {owner}",
    "Unnamed" : "Namnlös",
    "Important" : "Viktigt",
    "Week" : "Vecka",
    "All" : "Alla",
    "Current" : "Nuvarande",
    "Completed" : "Slutförande",
    "Delete" : "Radera",
    "Cancel" : "Avbryt",
    "Edit" : "Ändra",
    "Link" : "Länk",
    "Download" : "Ladda ned",
    "Save" : "Spara",
    "Add List..." : "Lägg till lista ...",
    "New List" : "Ny lista",
    "Settings" : "Inställningar",
    "Start of week" : "Början av vecka",
    "Visibility of Smart Collections" : "Synlighet av smarta samlingar",
    "Change sort order" : "Ändra sorteringsordning",
    "Default" : "Förvald",
    "Due date" : "Slutdatum",
    "Start date" : "Startdatum",
    "Priority" : "Prioritet",
    "Alphabetically" : "Alfabetisk",
    "Manually" : "Manuellt",
    "Load remaining completed tasks." : "Ladda återstående slutförda uppgifter.",
    "All day" : "Hela dagen",
    "(New category)" : "(Ny kategori)",
    "Select categories..." : "Välj kategorier...",
    "Loading the task..." : "Laddar uppgiften",
    "Task not found!" : "Uppgift ej hittad!",
    "add a subtask to" : "Lägg till en under-anteckning till"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.9.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/sv.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Uppgifter",
    "Due yesterday" : "Förföll igår",
    "Due today" : "Förfaller idag",
    "Due tomorrow" : "Förfaller imorgon",
    "Due on" : "Förfaller",
    "Started yesterday" : "Startade igår",
    "Starts today" : "Startar idag",
    "Starts tomorrow" : "Startar imorgon",
    "Started on" : "Startade",
    "Starts on" : "Startar på",
    "[Remind me yesterday at ]HH:mm" : "[Påminn mig igår kl ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Påminn mig idag kl ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Påminn mig imorgon kl ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Påminn mig den ]MMM DD, YYYY,[ kl ]HH:mm",
    "Yesterday" : "Igår",
    "Today" : "Idag",
    "Tomorrow" : "Imorgon",
    "in %s" : "om %s",
    "%s ago" : "%s sedan",
    "seconds" : "sekunder",
    "a minute" : "en minut",
    "%d minutes" : "%d minuter",
    "an hour" : "en timme",
    "%d hours" : "%d timmar",
    "a day" : "en dag",
    "%d days" : "%d dagar",
    "a month" : "en månad",
    "%d months" : "%d månader",
    "a year" : "ett år",
    "%d years" : "%d år",
    "week" : "vecka",
    "weeks" : "veckor",
    "day" : "dag",
    "days" : "dagar",
    "hour" : "timme",
    "hours" : "timmar",
    "minute" : "minut",
    "minutes" : "minuter",
    "second" : "sekund",
    "before beginning" : "före början",
    "after beginning" : "efter början",
    "before end" : "före utgång",
    "after end" : "efter utgång",
    "Comment" : "Kommentar",
    "Add a comment" : "Lägg till en kommentar",
    "This will delete the Calendar \"%s\" and all of its entries." : "Detta kommer att radera kalenderns \"%s\" och alla dess poster.",
    "The name \"%s\" is already used." : "Namnet \"%s\" används redan.",
    "An empty name is not allowed." : "Ett tomt namn är inte tillåtet.",
    "Hidden" : "Gömd",
    "Visible" : "Synlig",
    "Automatic" : "Automatisk",
    "Sunday" : "söndag",
    "Monday" : "måndag",
    "Tuesday" : "tisdag",
    "Wednesday" : "onsdag",
    "Thursday" : "torsdag",
    "Friday" : "fredag",
    "Saturday" : "lördag",
    "Add an important item in \"%s\"..." : "Lägg till en viktig post i \"%s\" ...",
    "Add an item due today in \"%s\"..." : "Lägg till en post som förfaller idag i \"%s\" ...",
    "Add an item in \"%s\"..." : "Lägg till en post i \"%s\" ...",
    "Add a current item in \"%s\"..." : "Lägg till en nuvarande post i \"%s\" ...",
    "Add a subtask to \"%s\"..." : "Lägg till en under-anteckning i \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n slutförda uppgifter","%n slutförda uppgifter"],
    "Hours" : "Timmar",
    "Minutes" : "Minuter",
    "Set due date" : "Sätt slutdatum",
    "%s %% completed" : "%s %% slutfört",
    "priority %s: " : "Prioritet %s:",
    "high" : "Hög",
    "medium" : "medium",
    "low" : "Låg",
    "no priority assigned" : "ingen prioritet tilldelad",
    "Remind me" : "Påminn mig",
    "at the end" : "vid slutet",
    "at the beginning" : "vid början",
    "Set start date" : "Sätt startdatum",
    "{calendar} shared by {owner}" : "{calendar} delad utav {owner}",
    "Unnamed" : "Namnlös",
    "Important" : "Viktigt",
    "Week" : "Vecka",
    "All" : "Alla",
    "Current" : "Nuvarande",
    "Completed" : "Slutförande",
    "Delete" : "Radera",
    "Cancel" : "Avbryt",
    "Edit" : "Ändra",
    "Link" : "Länk",
    "Download" : "Ladda ned",
    "Save" : "Spara",
    "Add List..." : "Lägg till lista ...",
    "New List" : "Ny lista",
    "Settings" : "Inställningar",
    "Start of week" : "Början av vecka",
    "Visibility of Smart Collections" : "Synlighet av smarta samlingar",
    "Change sort order" : "Ändra sorteringsordning",
    "Default" : "Förvald",
    "Due date" : "Slutdatum",
    "Start date" : "Startdatum",
    "Priority" : "Prioritet",
    "Alphabetically" : "Alfabetisk",
    "Manually" : "Manuellt",
    "Load remaining completed tasks." : "Ladda återstående slutförda uppgifter.",
    "Task is completed" : "Uppgift genomförd",
    "All day" : "Hela dagen",
    "(New category)" : "(Ny kategori)",
    "Select categories..." : "Välj kategorier...",
    "Loading the task..." : "Laddar uppgiften",
    "Task not found!" : "Uppgift ej hittad!",
    "add a subtask to" : "Lägg till en under-anteckning till",
    "Toggle subtasks" : "Växla underuppgifter",
    "Toggle completed subtasks" : "Växla färdiga underuppgifter"
},
"nplurals=2; plural=(n != 1);");
